/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;



//import static NPersistence.DiscriminatorType.STRING;

    /// <summary> Specifies the discriminator column for the 
    ///<para>
    /// <c>SINGLE_TABLE</c> and 
    /// </para>
    ///<para>
    /// <c>JOINED </c> <see cref="Inheritance"/> mapping strategies.
    /// </para>
    ///<para>
    ///  The strategy and the discriminator column are only 
    /// specified in the root of an entity class hierarchy or
    /// subhierarchy in which a different inheritance strategy is applied
    /// </para>
    ///<para>
    ///  If the <c>DiscriminatorColumn</c> annotation is missing, 
    /// and a discriminator column is required, the name of the 
    /// discriminator column defaults to <c>"DTYPE"</c> and the discriminator 
    /// type to <see cref="F:DiscriminatorType.STRING"/>.
    /// </para>
    /// <example><code>
    ///     Example:
    /// 
    ///     &#91;Entity&#93;
    ///     &#91;Table(name="CUST")&#93;
    ///     &#91;Inheritance(strategy=SINGLE_TABLE)&#93;
    ///     &#91;DiscriminatorColumn(name="DISC", discriminatorType=STRING, length=20)&#93;
    ///     public class Customer { ... }
    /// 
    ///     &#91;Entity&#93;
    ///     public class ValuedCustomer extends Customer { ... }
    /// </code></example>
    /// 
    /// <seealso cref="DiscriminatorValue"/>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Class)] 


public sealed class DiscriminatorColumn : System.Attribute {

    /// <summary> (Optional) The name of column to be used for the discriminator.
    /// </summary>
    public string Name = "DTYPE";

    /// <summary> (Optional) The type of object/column to use as a class discriminator.
    /// Defaults to <see cref="F:DiscriminatorType.STRING"/>.
    /// </summary>
    public DiscriminatorType DiscriminatorType = DiscriminatorType.STRING;

    /// <summary> (Optional) The SQL fragment that is used when generating the DDL 
    /// for the discriminator column.
    ///  Defaults to the provider-generated SQL to create a column 
    /// of the specified discriminator type.
    /// </summary>
    public string ColumnDefinition = "";

    /// <summary> 
    /// (Optional) The column length for String-based discriminator types. 
    /// Ignored for other discriminator types.
    /// </summary>
    public int Length = 31;
}
}