/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;


//import NPersistence.metamodel.Metamodel;
//import NPersistence.criteria.CriteriaBuilder;

/// <summary> Interface used to interact with the entity manager factory
/// for the persistence unit.
    /// <para> 
/// When the application has finished using the entity manager
/// factory, and/or at application shutdown, the application should
/// close the entity manager factory.  Once an
/// <c>EntityManagerFactory</c> has been closed, all its entity managers
/// are considered to be in the closed state.
/// </para>
/// 
/// </summary>
public interface EntityManagerFactory {

    /// <summary> Create a new application-managed <c>EntityManager</c>.
    /// This method returns a new <c>EntityManager</c> instance each time
    /// it is invoked. 
    /// The <c>isOpen</c> method will return true on the returned instance.
    /// <returns> entity manager instance</returns>
    /// <exception cref="InvalidOperationException"> if the entity manager factory
    /// has been closed</exception>
    /// </summary>
    EntityManager CreateEntityManager();
    
    /// <summary> Create a new application-managed <c>EntityManager</c> with the 
    /// specified Map of properties. 
    /// This method returns a new <c>EntityManager</c> instance each time
    /// it is invoked. 
    /// The <c>isOpen</c> method will return true on the returned instance.
    /// <param name="map"> properties for entity manager</param>
    /// <returns> entity manager instance</returns>
    /// <exception cref="InvalidOperationException"> if the entity manager factory
    /// has been closed</exception>
    /// </summary>
    EntityManager CreateEntityManager(Dictionary<object,object> map);

    /// <summary> Return an instance of <c>CriteriaBuilder</c> for the creation of
    /// <c>CriteriaQuery</c> objects.
    /// <returns> CriteriaBuilder instance</returns>
    /// <exception cref="InvalidOperationException"> if the entity manager factory 
    /// has been closed</exception>
    /// 
    /// 
    /// </summary>
//    CriteriaBuilder GetCriteriaBuilder();
    
    /// <summary> Return an instance of <c>Metamodel</c> interface for access to the
    /// metamodel of the persistence unit.
    /// <returns> Metamodel instance</returns>
    /// <exception cref="InvalidOperationException"> if the entity manager factory
    /// has been closed</exception>
    /// 
    /// 
    /// </summary>
//    Metamodel GetMetamodel();

    /// <summary> Indicates whether the factory is open. Returns true
    /// until the factory has been closed.
    /// <returns> boolean indicating whether the factory is open</returns>
    /// </summary>
    bool IsOpen();
    
    /// <summary> Close the factory, releasing any resources that it holds.
    /// After a factory instance has been closed, all methods invoked
    /// on it will throw the <c>InvalidOperationException</c>, except
    /// for <c>isOpen</c>, which will return false. Once an
    /// <c>EntityManagerFactory</c> has been closed, all its
    /// entity managers are considered to be in the closed state.
    /// <exception cref="InvalidOperationException"> if the entity manager factory
    /// has been closed</exception>
    /// </summary>
    void Close();

    /// <summary> Get the properties and associated values that are in effect
    /// for the entity manager factory. Changing the contents of the
    /// map does not change the configuration in effect.
    /// <returns> properties</returns>
    /// <exception cref="InvalidOperationException"> if the entity manager factory 
    /// has been closed</exception>
    /// 
    /// 
    /// </summary>
    Dictionary<string, object> GetProperties();

    /// <summary> Access the cache that is associated with the entity manager 
    /// factory (the "second level cache").
    /// <returns> instance of the <c>Cache</c> interface</returns>
    /// <exception cref="InvalidOperationException"> if the entity manager factory
    /// has been closed</exception>
    /// 
    /// 
    /// </summary>
    Cache GetCache();

    /// <summary> Return interface providing access to utility methods
    /// for the persistence unit.
    /// <returns> <c>PersistenceUnitUtil</c> interface</returns>
    /// <exception cref="InvalidOperationException"> if the entity manager factory
    /// has been closed</exception>
    /// 
    /// 
    /// </summary>
    PersistenceUnitUtil GetPersistenceUnitUtil();
}
}