/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

    /// <summary> Interface used to control transactions on resource-local entity
    /// managers.  The <see cref="EntityManager.GetTransaction"/> method returns the
    /// <c>EntityTransaction</c> interface.
    /// </summary>
public interface EntityTransaction {

     /// <summary>
    /// Start a resource transaction. </summary>  
     /// <exception cref="InvalidOperationException"> if <c>isActive()</c> is true</exception>
     
     void Begin();

     /// <summary>
     /// Commit the current resource transaction, writing any 
     /// unflushed changes to the database.</summary>   
     /// <exception cref="InvalidOperationException"> if <c>isActive()</c> is false</exception>
     /// <exception cref="RollbackException"> if the commit fails</exception>
     void Commit();

     /// <summary>
     /// Roll back the current resource transaction. </summary>  
     /// <exception cref="InvalidOperationException"> if <c>isActive()</c> is false</exception>
     /// <exception cref="PersistenceException"> if an unexpected error 
     ///         condition is encountered</exception>
     void Rollback();

     /// <summary>
     /// Mark the current resource transaction so that the only 
     /// possible outcome of the transaction is for the transaction 
     /// to be rolled back. </summary>  
     /// <exception cref="InvalidOperationException"> if <c>isActive()</c> is false</exception>
     void SetRollbackOnly();

     /// <summary>
     /// Determine whether the current resource transaction has been 
     /// marked for rollback.
     /// <returns> boolean indicating whether the transaction has been</returns>
     ///         marked for rollback</summary>  
     /// <exception cref="InvalidOperationException"> if <c>isActive()</c> is false</exception>
     bool GetRollbackOnly();

     /// <summary>
     /// Indicate whether a resource transaction is in progress.</summary>  
     /// <returns> boolean indicating whether transaction is</returns>
     ///         in progress
     /// <exception cref="PersistenceException"> if an unexpected error 
     ///         condition is encountered</exception>
     bool IsActive();
}
}