/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

    /// <summary> Defines strategies for fetching data from the database.
    /// <para>
    /// The <c>EAGER</c> strategy is a requirement on the persistence 
    /// provider runtime that data must be eagerly fetched. 
    /// </para>
    /// <para>
    /// The <c>LAZY</c> strategy is a hint to the persistence provider 
    /// runtime that data should be fetched lazily when it is 
    /// first accessed.
    /// </para>
    /// <para>
    /// The implementation is permitted to eagerly 
    /// fetch data for which the <c>LAZY</c> strategy hint has been 
    /// specified. 
    /// </para>
    /// <example><code>
    ///   Example:
    ///   &#91;Basic(fetch=LAZY)&#93;
    ///   protected String getName() { return name; }
    /// </code></example>
    /// 
    /// <seealso cref="Basic"/>
    /// <seealso cref="ElementCollection"/>
    /// <seealso cref="ManyToMany"/>
    /// <seealso cref="OneToMany"/>
    /// <seealso cref="ManyToOne"/>
    /// <seealso cref="OneToOne"/>
    /// 
    /// </summary>
    public enum FetchType {

    /// <summary> Defines that data can be lazily fetched.
    /// </summary>
    LAZY,

    /// <summary> Defines that data must be eagerly fetched.
    /// </summary>
    EAGER
}
}