/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

/// <summary> Flush mode setting.
    /// <para>
///  When queries are executed within a transaction, if
    /// <c>FlushModeType.AUTO</c> is set on the <see cref="NPersistence.Query"/> or <see cref="T:NPersistence.TypedQuery`1"/>
    /// object, or if the flush mode setting for the
/// persistence context is <c>AUTO</c> (the default) and a flush
/// mode setting has not been specified for the <c>Query</c> or
/// <c>TypedQuery</c> object, the persistence provider is
/// responsible for ensuring that all updates to the state of all
/// entities in the persistence context which could potentially affect
/// the result of the query are visible to the processing of the
/// query. 
    /// </para>
    /// <para>
/// The persistence provider implementation may achieve this by
/// flushing those entities to the database or by some other means. 
///  If <c>FlushModeType.COMMIT</c> is set, the effect of
/// updates made to entities in the persistence context upon queries is
/// unspecified.
    /// </para>
    /// <para>
///  If there is no transaction active, the persistence provider 
/// must not flush to the database.
/// </para>
/// 
/// </summary>
public enum FlushModeType {

    /// <summary> Flushing to occur at transaction commit.  The provider may flush
    ///  at other times, but is not required to.
    /// </summary>
   COMMIT,

    /// <summary> (Default) Flushing to occur at query execution.
    /// </summary>
   AUTO
}
}