/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

//import static NPersistence.InheritanceType.SINGLE_TABLE;

/// <summary> Defines the inheritance strategy to be used for an entity class
/// hierarchy. It is specified on the entity class that is the root of
/// the entity class hierarchy.
    /// <para>
/// If the <c>Inheritance</c> annotation is not
/// specified or if no inheritance type is specified for an entity
/// class hierarchy, the <c>SINGLE_TABLE</c> mapping strategy is used.
/// </para>
/// <example><code>
/// 
///   Example:
/// 
///   &#91;Entity&#93;
///   &#91;Inheritance(strategy=JOINED)&#93;
///   public class Customer { ... }
/// 
///   &#91;Entity&#93;
///   public class ValuedCustomer extends Customer { ... }
/// </code></example>
/// 
/// 
/// </summary>
[System.AttributeUsage(System.AttributeTargets.Class)]


public sealed class Inheritance : System.Attribute {

    /// <summary> The strategy to be used for the entity inheritance hierarchy.
    /// </summary>
    public InheritanceType Strategy = InheritanceType.SINGLE_TABLE;
}
}