/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;


    /// <summary> Specifies that a persistent property or field should be persisted
    /// as a large object to a database-supported large object type.
    /// <para>
    ///  Portable applications should use the <c>Lob</c> annotation
    /// when mapping to a database Lob type.  The <c>Lob</c>
    /// annotation may be used in conjunction with the <see cref="Basic"/>
    /// annotation or the <see cref="ElementCollection"/> annotation when the
    /// element collection value is of basic type. A <c>Lob</c> may
    /// be either a binary or character type.
    /// </para>
    /// <para>
    ///  The <c>Lob</c> type is inferred from the type of the 
    /// persistent field or property, and except for string and 
    /// character-based types defaults to Blob.
    /// </para>
    /// <example><code>
    /// 
    ///   Example 1:
    /// 
    ///   &#91;Lob&#93; &#91;Basic(fetch=LAZY)
    ///   &#91;Column(name="REPORT")
    ///   protected String report;
    /// 
    ///   Example 2:
    /// 
    ///   &#91;Lob&#93; &#91;Basic(fetch=LAZY)&#93;
    ///   &#91;Column(name="EMP_PIC", columnDefinition="BLOB NOT NULL")&#93;
    ///   protected byte[] pic;
    /// 
    /// </code></example>
    /// 
    /// <seealso cref="Basic"/>
    /// <seealso cref="ElementCollection"/>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)] 

public sealed class Lob : System.Attribute {
}
}