/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;


    /// <summary> Specifies the map key for associations of type 
    /// <see cref="T:System.Collections.Generic.Dictionary`2"/> when the map key is itself the primary
    /// key or a persistent field or property of the entity that is
    /// the value of the map.
    /// <para>
    ///  If a persistent field or property other than the primary 
    /// key is used as a map key then it is expected to have a 
    /// uniqueness constraint associated with it.
    /// </para>
    /// <para>
    /// 
    ///  The <see cref="MapKeyClass"/> annotation is not used when
    /// <c>MapKey</c> is specified and vice versa.
    /// </para>
    /// <example><code>
    /// 
    ///    Example 1:
    /// 
    ///    &#91;Entity&#93;
    ///    public class Department {
    ///        ...
    ///        &#91;OneToMany(mappedBy="department")&#93;
    ///        &#91;MapKey&#93;  // map key is primary key
    ///        public Dictionary&#060;Integer, Employee&#062; getEmployees() {... }
    ///        ...
    ///    }
    /// 
    ///    &#91;Entity&#93;
    ///    public class Employee {
    ///        ...
    ///        &#91;Id&#93; Integer getEmpId() { ... }
    ///        &#91;ManyToOne&#93;
    ///        &#91;JoinColumn(name="dept_id")&#93;
    ///        public Department getDepartment() { ... }
    ///        ...
    ///    }
    /// 
    ///    Example 2:
    /// 
    ///    &#91;Entity&#93;
    ///        public class Department {
    ///        ...
    ///        &#91;OneToMany(mappedBy="department")&#93;
    ///        &#91;MapKey(name="name")&#93;
    ///        public Dictionary&#060;String, Employee&#062; getEmployees() {... }
    ///        ...
    ///    }
    /// 
    ///    &#91;Entity&#93;
    ///        public class Employee {
    ///        &#91;Id&#93; public Integer getEmpId() { ... }
    ///        ...
    ///        &#91;ManyToOne&#93;
    ///        &#91;JoinColumn(name="dept_id")&#93;
    ///        public Department getDepartment() { ... }
    ///        ...
    ///    }
    /// </code></example>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)] 

public sealed class MapKey : System.Attribute {

    /// <summary> (Optional) The name of the persistent field or property of the 
    /// associated entity that is used as the map key. 
    ///  Default: If the 
    /// <c>name</c> element is not specified, the primary key of the 
    /// associated entity is used as the map key. If the 
    /// primary key is a composite primary key and is mapped 
    /// as <c>IdClass</c>, an instance of the primary key 
    /// class is used as the key.
    /// </summary>
    public string Name = "";
}
}