/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

    /// <summary> This annotation must be specified for persistent map keys of type 
    /// <see cref="System.DateTime"/>. 
    /// <para>
    /// It may only be 
    /// specified for map keys of these types.
    /// </para>
    /// <para>
    ///  The <c>MapKeyTemporal</c> annotation can be applied to an
    /// element collection or relationship of type <c>System.Collections.Generic.Dictionary</c>
    /// in conjunction with the <c>ElementCollection</c>,
    /// <c>OneToMany</c>, or <c>ManyToMany</c> annotation.
    /// </para>
    /// <example><code>
    ///     Example:
    /// 
    ///     &#91;OneToMany&#93;
    ///     &#91;MapKeyTemporal(DATE)&#93;
    ///     protected System.Collections.Generic.Dictionary&#060;System.DateTime, Employee&#062; employees;
    /// </code></example>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)] 

public sealed class MapKeyTemporal : System.Attribute {

    /// <summary> (Required) The type used in mapping
    /// <c>System.DateTime</c> or
    /// <c>System.DateTime</c>. 
    /// </summary>
    public TemporalType Value; public MapKeyTemporal() {} public MapKeyTemporal(TemporalType value) { Value = value; } 
}

}