/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;


    /// <summary> Designates a class whose mapping information is applied 
    /// to the entities that inherit from it. 
    /// <para>
    /// A mapped superclass 
    /// has no separate table defined for it.  
    /// </para><para>
    ///  A class designated with the <c>MappedSuperclass</c> 
    /// annotation can be mapped in the same way as an entity except that the 
    /// mappings will apply only to its subclasses since no table 
    /// exists for the mapped superclass itself. 
    /// </para><para>
    /// When applied to the 
    /// subclasses the inherited mappings will apply in the context 
    /// of the subclass tables. Mapping information may be overridden 
    /// in such subclasses by using the <c>AttributeOverride</c> and 
    /// <c>AssociationOverride</c> annotations or corresponding XML elements.
    /// </para>
    /// <example><code>
    ///    Example: Concrete class as a mapped superclass
    /// 
    ///    &#91;MappedSuperclass&#93;
    ///    public class Employee {
    ///    
    ///        &#91;Id&#93; protected Integer empId;
    ///        &#91;Version&#93; protected Integer version;
    ///        &#91;ManyToOne&#93; &#91;JoinColumn(name="ADDR")&#93;
    ///        protected Address address;
    ///    
    ///        public Integer getEmpId() { ... }
    ///        public void setEmpId(Integer id) { ... }
    ///        public Address getAddress() { ... }
    ///        public void setAddress(Address addr) { ... }
    ///    }
    ///    
    ///    // Default table is FTEMPLOYEE table
    ///    &#91;Entity&#93;
    ///    public class FTEmployee extends Employee {
    ///    
    ///        // Inherited empId field mapped to FTEMPLOYEE.EMPID
    ///        // Inherited version field mapped to FTEMPLOYEE.VERSION
    ///        // Inherited address field mapped to FTEMPLOYEE.ADDR fk
    ///    
    ///        // Defaults to FTEMPLOYEE.SALARY
    ///        protected Integer salary;
    ///    
    ///        public FTEmployee() {}
    ///    
    ///        public Integer getSalary() { ... }
    ///    
    ///        public void setSalary(Integer salary) { ... }
    ///    }
    ///    
    ///    &#91;Entity&#93; &#91;Table(name="PT_EMP")&#93;
    ///    &#91;AssociationOverride(Name="address")&#93;
    ///    &#91;JoinColumn(AttributeRef="address",Name="ADDR_ID")&#93;
    ///    public class PartTimeEmployee extends Employee {
    ///    
    ///        // Inherited empId field mapped to PT_EMP.EMPID
    ///        // Inherited version field mapped to PT_EMP.VERSION
    ///        // address field mapping overridden to PT_EMP.ADDR_ID fk
    ///        &#91;Column(name="WAGE")&#93;
    ///        protected Float hourlyWage;
    ///    
    ///        public PartTimeEmployee() {}
    ///    
    ///        public Float getHourlyWage() { ... }
    ///        public void setHourlyWage(Float wage) { ... }
    ///    }
    /// </code></example>
    /// 
    /// <seealso cref="AttributeOverride "/>
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Class)]/*@Documented*/


public sealed class MappedSuperclass : System.Attribute {
}
}