/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel -Java Persistence 2.0 - Proposed Final Draft, Version 2.0 (August 31, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;


    /// <summary> Designates a <c>ManyToOne</c> or
    /// <c>OneToOne</c> relationship attribute that provides the
    /// mapping for an <see cref="EmbeddedId"/> primary key, an attribute within
    /// an <c>EmbeddedId</c> primary key, or a simple primary key of
    /// the parent entity. 
    /// <para>
    /// The <c>value</c> element specifies the
    /// attribute within a composite key to which the relationship
    /// attribute corresponds. If the entity's primary key is of the same 
    /// type as the primary key of the entity referenced by the
    /// relationship, the value attribute is not specified.
    /// </para>
    /// <example><code>
    ///    Example:
    /// 
    ///    // parent entity has simple primary key
    /// 
    ///    &#91;Entity&#93;
    ///    public class Employee {
    ///       &#91;Id&#93; long empId;
    ///       String name;
    ///       ...
    ///    } 
    /// 
    ///    // dependent entity uses EmbeddedId for composite key
    /// 
    ///    &#91;Embeddable&#93;
    ///    public class DependentId {
    ///       String name;
    ///       long empid;   // corresponds to primary key type of Employee
    ///    }
    /// 
    ///    &#91;Entity&#93;
    ///    public class Dependent {
    ///       &#91;EmbeddedId&#93; DependentId id;
    ///        ...
    ///       &#91;MapsId("empid")&#93;  //  maps the empid attribute of embedded id
    ///       &#91;ManyToOne&#93; Employee emp;
    ///    }
    /// </code></example>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)]/*@Target( { METHOD, FIELD })*/

public sealed class MapsId : System.Attribute {

    /// <summary> (Optional) The name of the attribute within the composite key
    /// to which the relationship attribute corresponds.  If not
    /// supplied, the relationship maps the entitys primary
    /// key.
    /// </summary>
   public string Value = ""; public MapsId() {} public MapsId(string value) { Value = value; }  }
}