/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

/// <summary> Type for query parameter objects.
    /// <typeparam name="T">  the type of the parameter</typeparam>
    /// </summary>
/// <seealso cref="Query"/>
/// <seealso cref="T:TypedQuery`1"/>
/// 
/// 

public interface Parameter<T> {

    /// <summary> Return the parameter name, or null if the parameter is
    /// not a named parameter or no name has been assigned.</summary>
    /// <returns> parameter name</returns>
    /// 
    string GetName();

    /// <summary> Return the parameter position, or null if the parameter
    /// is not a positional parameter. </summary>
    /// <returns> position of parameter</returns>
    /// 
    int? GetPosition();

    /// <summary> Return the type of the parameter. Values bound to the
    /// parameter must be assignable to this type.
    /// This method is required to be supported for criteria queries
    /// only.   Applications that use this method for Java 
    /// Persistence query language queries and native queries will 
    /// not be portable.</summary>
    /// <returns> the type of the parameter</returns>
    /// <exception cref="InvalidOperationException"> if invoked on a parameter
    ///         obtained from a Java persistence query language 
    ///         query or native query when the implementation does 
    ///         not support this use</exception>
    /// 
     System.Type GetParameterType();
}

}