/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

/// <summary> Utility interface between the application and the persistence
/// provider managing the persistence unit.
    /// <para>
/// The methods of this interface should only be invoked on entity
/// instances obtained from or managed by entity managers for this
/// persistence unit or on new entity instances.
/// </para>
/// 
/// </summary>
public interface PersistenceUnitUtil : PersistenceUtil {

    /// <summary> Determine the load state of a given persistent attribute
    /// of an entity belonging to the persistence unit.
    /// <param name="entity">  entity instance containing the attribute</param>
    /// <param name="attributeName"> name of attribute whose load state is</param>
    ///        to be determined
    /// <returns> false if entity's state has not been loaded or if </returns>
    ///         the attribute state has not been loaded, else true
    /// </summary>
    new bool IsLoaded(object entity, string attributeName);

    /// <summary> Determine the load state of an entity belonging to the
    /// persistence unit.  This method can be used to determine the
    /// load state of an entity passed as a reference.  An entity is
    /// considered loaded if all attributes for which
    /// <c>FetchType.EAGER</c> has been specified have been
    /// loaded.  
    ///  The <c>isLoaded(Object, String)</c> method
    /// should be used to determine the load state of an attribute.
    /// Not doing so might lead to unintended loading of state.
    /// <param name="entity">   entity instance whose load state is to be determined</param>
    /// <returns> false if the entity has not been loaded, else true</returns>
    /// </summary>
    new bool IsLoaded(object entity);

    /// <summary>  Return the id of the entity.
    ///  A generated id is not guaranteed to be available until after
    ///  the database insert has occurred.
    ///  Returns null if the entity does not yet have an id.
    ///  <param name="entity">  entity instance</param>
    ///  <returns> id of the entity</returns>
    ///  <exception cref="ArgumentException"> if the object is found not 
    ///          to be an entity</exception>
    /// </summary>
    object GetIdentifier(object entity);
} 
}