/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

/// <summary> Thrown by the persistence provider when a query times out
/// and only the statement is rolled back.
    ///<para>
/// The current transaction, if one is active, will be not
/// be marked for rollback.
/// </para>
/// 
/// </summary>
public class QueryTimeoutException : PersistenceException {

    /// <summary> The query object that caused the exception/// </summary>
    internal Query query;

    /// <summary> 
    /// Constructs a new <c>QueryTimeoutException</c> exception 
    /// with <c>null</c> as its detail message.
    /// </summary>
    public QueryTimeoutException() : base() {
        // super(...) -> base(...)
    }

    /// <summary> 
    /// Constructs a new <c>QueryTimeoutException</c> exception 
    /// with the specified detail message.
    /// </summary>
    /// <param name="message">the detail message.</param>
    
    public QueryTimeoutException(string message) : base(message) {
        // super(...) -> base(...)
    }

    /// <summary> 
    /// Constructs a new <c>QueryTimeoutException</c> exception 
    /// with the specified detail message and cause.
    /// </summary>
    /// <param name="message">the detail message.</param>
    /// <param name="cause">the cause.</param>
    
    public QueryTimeoutException(string message, System.Exception cause) : base(message, cause) {
        // super(...) -> base(...)
    }

    /// <summary> 
    /// Constructs a new <c>QueryTimeoutException</c> exception 
    /// with the specified cause.
    /// </summary>
    /// <param name="cause">the cause.</param>
    
    public QueryTimeoutException(System.Exception cause) : base(cause) {
        // super(...) -> base(...)
    }


    /// <summary> 
    /// Constructs a new <c>QueryTimeoutException</c> exception 
    /// with the specified query.
    /// </summary>
    /// <param name="query">the query.</param>
    
    public QueryTimeoutException(Query query) {
        this.query = query;
    }

    /// <summary> 
    /// Constructs a new <c>QueryTimeoutException</c> exception 
    /// with the specified detail message, cause, and query.
    /// </summary>
    /// <param name="message">the detail message.</param>
    /// <param name="cause">the cause.</param>
    /// <param name="query">the query.</param>
    
    public QueryTimeoutException(string message, System.Exception cause, Query query) : base(message, cause) {
        // super(...) -> base(...)
        this.query = query;
    }
    
    /// <summary> Returns the query that caused this exception.
    /// </summary>
    /// <returns> the query.</returns>
    
    public Query GetQuery() {
        return this.query;
    }
}


}