/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

    /// <summary> Defines a primary key generator that may be referenced by name when
    /// a generator element is specified for the <see cref="GeneratedValue"/>
    /// annotation.
    /// <para>
    /// A sequence generator may be specified on the entity
    /// class or on the primary key field or property. 
    /// </para><para>
    /// The scope of the
    /// generator name is global to the persistence unit (across all
    /// generator types).
    /// </para>
    /// <example><code>
    ///   Example:
    /// 
    ///   &#91;SequenceGenerator(name="EMP_SEQ", allocationSize=25)&#93;
    /// </code></example>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Class | System.AttributeTargets.Field | System.AttributeTargets.Property)] 

public sealed class SequenceGenerator : System.Attribute {

    /// <summary> 
    /// (Required) A unique generator name that can be referenced 
    /// by one or more classes to be the generator for primary key 
    /// values.
    /// </summary>
    public string Name;

    /// <summary> (Optional) The name of the database sequence object from 
    /// which to obtain primary key values.
    ///  Defaults to a provider-chosen value.
    /// </summary>
    public string SequenceName = "";

    /// <summary> (Optional) The catalog of the sequence generator. 
    /// 
    /// 
    /// </summary>
    public string Catalog = "";

    /// <summary> (Optional) The schema of the sequence generator. 
    /// 
    /// 
    /// </summary>
    public string Schema = "";

    /// <summary> 
    /// (Optional) The value from which the sequence object 
    /// is to start generating.
    /// </summary>
    public int InitialValue = 1;

    /// <summary> (Optional) The amount to increment by when allocating 
    /// sequence numbers from the sequence.
    /// </summary>
    public int AllocationSize = 50;
}
}