/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

/// <summary> Specifies how the provider must use a second-level cache for the
/// persistence unit.  
    /// <para>
/// Corresponds to the value of the <c>persistence.xml</c>
/// <c>shared-cache-mode</c> element, and returned as the result of
    /// <see cref="NPersistence.spi.PersistenceUnitInfo.GetSharedCacheMode()"/>.
/// </para>
/// 
/// </summary>
public enum SharedCacheMode {

    /// <summary> All entities and entity-related state and data are cached.
    /// </summary>
    ALL, 

    /// <summary> Caching is disabled for the persistence unit.
    /// </summary>
    NONE, 

    /// <summary> Caching is enabled for all entities for <c>Cacheable(true)</c>
    /// is specified.  All other entities are not cached.
    /// </summary>
    ENABLE_SELECTIVE, 

    /// <summary> Caching is enabled for all entities except those for which
    /// <c>Cacheable(false)</c> is specified.  Entities for which
    /// <c>Cacheable(false)</c> is specified are not cached.
    /// </summary>
    DISABLE_SELECTIVE, 

    /// <summary> 
    /// Caching behavior is undefined: provider-specific defaults may apply.
    /// </summary>
    UNSPECIFIED
}
}