/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;



    /// <summary> Specifies that a unique constraint is to be included in
    /// the generated DDL for a primary or secondary table.
    /// 
    /// <example>
    /// <code>
    ///    Example:
    ///    &#91;Entity&#93;
    ///    &#91;Table(Name="EMPLOYEE") &#93;
    ///         &#91;UniqueConstraint(TableRef = "EMPLOYEE", columnNames={"EMP_ID", "EMP_NAME"})&#93;
    ///    )
    ///    public class Employee { ... }
    /// 
    /// </code></example>
    /// <example><code>
    /// 
    ///    Example2:
    /// 
    ///    &#91;JoinTable(name="CUST_PHONE")&#93;
    ///       &#91;JoinColumn(AttributeRef="CUST_PHONE",name="CUST_ID", referencedColumnName="ID")&#93;
    ///       &#91;JoinColumn(AttributeRef="CUST_PHONE",name="PHONE_ID", referencedColumnName="ID", Inverse=true)&#93;
    ///       &#91;UniqueConstraint(TableRef = "CUST_PHONE", ColumnNames = new String[] { "CUST_ID", "PHONE_ID" })&#93;
    ///    )
    /// </code></example>
    /// 
    /// </summary>

    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property | System.AttributeTargets.Class, AllowMultiple = true)]
public sealed class UniqueConstraint : System.Attribute {

    /// <summary>
    /// (Required) Specifies the Table, JoinTable, SecondaryTable or TableGenerator attribute which this UniqueConstraint attribute belongs to.
    /// 
    /// This Unique constraint represents a Unique constraint that is to be placed on 
    /// the table. it is only used if table generation is in 
    /// effect. the constraint applys in addition to any constraints 
    /// specified by the <c>Column</c> and <c>JoinColumn</c> 
    /// annotations and constraints entailed by primary key mappings.
    ///  Defaults to no additional constraints
    /// </summary>
    public string TableRef = "";

    /// <summary> (Optional) Constraint name.  A provider-chosen name will be chosen
    /// if a name is not specified.
    /// 
    /// 
    /// </summary>
    public string Name = "";

    /// <summary> (Required) An array of the column names that make up the constraint
    /// </summary>
    public string[] ColumnNames;
}
}