/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence.spi { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;



/// <summary> Determine the list of persistence providers available in the 
/// runtime environment.
/// <para>
///  Implementations must be thread-safe.
    /// </para>
    /// <para>
///  Note that the <c>getPersistenceProviders</c> method can potentially
/// be called many times: it is recommended that the implementation
/// of this method make use of caching.
/// </para>
    /// <seealso cref="PersistenceProvider"/>
/// </summary>
public interface PersistenceProviderResolver {

    /// <summary> Returns a list of the <c>PersistenceProvider</c> implementations 
    /// available in the runtime environment.
    /// 
    /// </summary>
    /// <returns> list of the persistence providers available 
    ///         in the environment</returns>
    
    IList<PersistenceProvider> GetPersistenceProviders();

    /// <summary> Clear cache of providers.
    /// 
    /// </summary>
    void ClearCachedProviders();
} 
}