/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence.spi { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

/// <summary> Utility interface implemented by the persistence provider.  This
/// interface is invoked by the 
    /// <see cref="NPersistence.PersistenceUtil"/> implementation to determine
/// the load status of an entity or entity attribute.
/// 
/// </summary>
public interface ProviderUtil { 

    /// <summary> If the provider determines that the entity has been provided
    /// by itself and that the state of the specified attribute has
    /// been loaded, this method returns <c>LoadState.LOADED</c>.
    ///  If the provider determines that the entity has been provided
    /// by itself and that either entity attributes with <c>FetchType.EAGER</c> 
    /// have not been loaded or that the state of the specified
    /// attribute has not been loaded, this methods returns
    /// <c>LoadState.NOT_LOADED</c>.
    ///  If a provider cannot determine the load state, this method
    /// returns <c>LoadState.UNKNOWN</c>.
    ///  The provider's implementation of this method must not obtain
    /// a reference to an attribute value, as this could trigger the
    /// loading of entity state if the entity has been provided by a
    /// different provider.
    /// </summary>
    /// <param name="entity">  entity instance</param>
    /// <param name="attributeName">  name of attribute whose load status is
    ///        to be determined</param>
    /// <returns>load status of the attribute</returns>
    
    LoadState IsLoadedWithoutReference(object entity, string attributeName);

    /// <summary> If the provider determines that the entity has been provided
    /// by itself and that the state of the specified attribute has
    /// been loaded, this method returns <c>LoadState.LOADED</c>.
    ///  If a provider determines that the entity has been provided
    /// by itself and that either the entity attributes with <c>FetchType.EAGER</c>
    /// have not been loaded or that the state of the specified
    /// attribute has not been loaded, this method returns
    /// return <c>LoadState.NOT_LOADED</c>.
    ///  If the provider cannot determine the load state, this method
    /// returns <c>LoadState.UNKNOWN</c>.
    ///  The provider's implementation of this method is permitted to
    /// obtain a reference to the attribute value.  (This access is
    /// safe because providers which might trigger the loading of the
    /// attribute state will have already been determined by
    /// <c>isLoadedWithoutReference</c>. )
    /// 
    /// </summary>
    /// <param name="entity">entity instance</param>
    /// <param name="attributeName">name of attribute whose load status is
    ///        to be determined</param>
    /// <returns> load status of the attribute</returns>
    
    LoadState IsLoadedWithReference(object entity, string attributeName);

    /// <summary> If the provider determines that the entity has been provided
    /// by itself and that the state of all attributes for which
    /// <c>FetchType.EAGER</c> has been specified have been loaded, this 
    /// method returns <c>LoadState.LOADED</c>.
    ///  If the provider determines that the entity has been provided
    /// by itself and that not all attributes with <c>FetchType.EAGER</c> 
    /// have been loaded, this method returns <c>LoadState.NOT_LOADED</c>.
    ///  If the provider cannot determine if the entity has been
    /// provided by itself, this method returns <c>LoadState.UNKNOWN</c>.
    ///  The provider's implementation of this method must not obtain
    /// a reference to any attribute value, as this could trigger the
    /// loading of entity state if the entity has been provided by a
    /// different provider.
    /// </summary>
    /// <param name="entity">whose loaded status is to be determined</param> 
    /// <returns> load status of the entity</returns>
    
    LoadState IsLoaded(object entity);
}
}